import { blogPosts, formatDate } from '@/components/BlogList';
import Footer from '@/components/Footer';
import Navbar from '@/components/Navbar';
import { Button } from '@/components/ui/button';
import { Link, usePage } from '@inertiajs/react';
import { ArrowLeft, Calendar, ChevronLeft, ChevronRight } from 'lucide-react';
import { useEffect, useState } from 'react';

type BlogPostType = {
    id: number;
    title: string;
    excerpt: string;
    author: string;
    date: string;
    image: string;
    category: string;
};

const BlogPost = () => {
    const { props } = usePage();
    const id = props.id;
    const [post, setPost] = useState<BlogPostType | null>(null);
    const [nextPost, setNextPost] = useState<BlogPostType | null>(null);
    const [prevPost, setPrevPost] = useState<BlogPostType | null>(null);

    useEffect(() => {
        if (!id) return;

        const postId = parseInt(String(id), 10);
        const currentPost = blogPosts.find((p) => p.id === postId);

        if (!currentPost) {
            return;
        }

        setPost(currentPost);

        // Get next and previous posts
        const currentIndex = blogPosts.findIndex((p) => p.id === postId);
        if (currentIndex > 0) {
            setPrevPost(blogPosts[currentIndex - 1]);
        } else {
            setPrevPost(null);
        }

        if (currentIndex < blogPosts.length - 1) {
            setNextPost(blogPosts[currentIndex + 1]);
        } else {
            setNextPost(null);
        }
    }, [id]);

    if (!post) {
        return <div className="flex min-h-screen items-center justify-center">Loading...</div>;
    }

    return (
        <div className="min-h-screen">
            <Navbar />
            <div className="pt-24 pb-16">
                <div className="mx-auto max-w-4xl px-4">

                    <div className="mt-8 mb-12 overflow-hidden rounded-xl bg-white shadow-md">
                        <div className="relative h-80">
                            <img src={post.image} alt={post.title} className="h-full w-full object-cover" />
                            <div className="absolute right-0 bottom-0 left-0 bg-gradient-to-t from-black/80 to-transparent p-8">
                                <span className="bg-primary rounded-full px-3 py-1 text-sm font-bold text-white">{post.category}</span>
                                <h1 className="font-display mt-4 text-3xl font-bold text-white md:text-4xl">{post.title}</h1>
                            </div>
                        </div>

                        <div className="p-8">
                            <div className="mb-6 flex items-center text-sm text-gray-500">
                                <Calendar size={16} className="mr-1" />
                                <span>{formatDate(post.date)}</span>
                                <span className="mx-2">•</span>
                                <span>By {post.author}</span>
                            </div>

                            <div className="prose max-w-none">
                                <p>
                                    Sri Lanka, the teardrop-shaped island in the Indian Ocean, is a traveler's paradise with diverse landscapes, rich
                                    culture, and warm hospitality. From pristine beaches to misty mountains, ancient ruins to vibrant wildlife, this
                                    compact destination offers experiences that will captivate your heart and soul.
                                </p>
                                <p>
                                    The island nation boasts eight UNESCO World Heritage Sites, showcasing its rich historical and natural
                                    significance. The ancient cities of Anuradhapura, Polonnaruwa, and the rock fortress of Sigiriya stand as
                                    testaments to Sri Lanka's glorious past and architectural prowess.
                                </p>
                                <p>
                                    Wildlife enthusiasts will be thrilled by the opportunity to spot leopards, elephants, and a myriad of bird species
                                    in national parks like Yala and Wilpattu. The country's commitment to conservation has resulted in protected areas
                                    that serve as havens for diverse flora and fauna.
                                </p>
                                <h2 className="mt-6 mb-3 text-xl font-bold">What makes {post.title} special?</h2>
                                <p>
                                    For those seeking relaxation, Sri Lanka's coastline offers golden beaches washed by the azure waters of the Indian
                                    Ocean. From the popular stretches in Bentota and Unawatuna to the less-explored bays in the east, beach lovers are
                                    spoilt for choice.
                                </p>
                                <p>
                                    The central highlands, with their tea plantations and cool climate, provide a stark contrast to the coastal
                                    plains. Nuwara Eliya, often called 'Little England,' charms visitors with its colonial architecture and
                                    mist-covered hills.
                                </p>
                                <p>
                                    Sri Lankan cuisine is another highlight, with its bold flavors and aromatic spices. From rice and curry to hoppers
                                    and kottu roti, the island's culinary delights are as diverse as its landscapes.
                                </p>
                                <p>
                                    But perhaps, the most endearing aspect of Sri Lanka is its people. The warm smiles, the genuine hospitality, and
                                    the eagerness to share their culture and traditions make every visitor feel at home.
                                </p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <Footer />
        </div>
    );
};

export default BlogPost;
